"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseGoModGraph = void 0;
const dep_graph_1 = require("@snyk/dep-graph");
const types_1 = require("../types");
// Modules can be of shape `modules/snyk/inner/v2` or `modules/snyk/v2/inner`
const GO_SEMVER_PREFIXED_MODULES_REGEX = /(.*)\/v[0-9]+(.*)/;
const GO_MODULES = 'gomodules';
function parseGoModGraphLine(line) {
    return line
        .trim()
        .split(/\s/)
        .map((item) => item.split('@'))
        .map(([name, v]) => {
        // Handle cases for prefixed-semver, see https://golang.org/ref/mod#major-version-suffixes
        return [name.replace(GO_SEMVER_PREFIXED_MODULES_REGEX, '$1$2'), v];
    });
}
function parseGoModGraph(goModGraphOutput, projectName, projectVersion = types_1.DEFAULT_INITIAL_VERSION) {
    const iterationReadyGraph = goModGraphOutput
        .trim()
        .split('\n')
        .filter(Boolean);
    const rootPkgInfo = {
        name: projectName || getModuleName(iterationReadyGraph[0]),
        version: projectVersion,
    };
    const depGraph = new dep_graph_1.DepGraphBuilder({ name: GO_MODULES }, rootPkgInfo);
    for (const line of iterationReadyGraph) {
        const [[parentName, parentVersion = types_1.DEFAULT_INITIAL_VERSION], [childName, childVersion],] = parseGoModGraphLine(line);
        const parentPkg = { name: parentName, version: parentVersion };
        const childPkg = {
            name: childName,
            version: childVersion || types_1.DEFAULT_INITIAL_VERSION,
        };
        const parentNodeId = parentName === rootPkgInfo.name
            ? types_1.DEFAULT_ROOT_NODE_NAME
            : `${parentName}@${parentVersion}`;
        const childNodeId = `${childPkg.name}@${childPkg.version}`;
        if (parentPkg.name !== rootPkgInfo.name) {
            depGraph.addPkgNode(parentPkg, parentNodeId);
        }
        depGraph.addPkgNode(childPkg, childNodeId);
        depGraph.connectDep(parentNodeId, childNodeId);
    }
    return depGraph.build();
}
exports.parseGoModGraph = parseGoModGraph;
function getModuleName(firstLine = '') {
    const [[moduleName]] = parseGoModGraphLine(firstLine);
    return moduleName || 'empty';
}
//# sourceMappingURL=gomod-graph-parser.js.map